@@ -836,7 +836,7 @@ sub post_invoice {
 
   $form->{taxincluded} *= 1;
 
-  foreach $i (1 .. $form->{rowcount}) {
+  foreach my $i (1 .. $form->{rowcount}) {
     $form->{"qty_$i"} = $form->parse_amount($myconfig, $form->{"qty_$i"}) * $sw;
     
     if ($form->{"qty_$i"}) {
